@@ -107,4 +107,39 @@ class Database():
         
         self.connection.commit()
         
-        print("Successfully inserted a new record into the {table} table.".format(table=table))
\ No newline at end of file
+        print("Successfully inserted a new record into the {table} table.".format(table=table))
+    
+    def update_by_id(self, table, columns, values, row_id):
+        """ Updates a table record's values based on the given row Id """
+        
+        sql = "UPDATE {table} SET ".format(table=table)
+        
+        for column in columns:
+            sql += "{column} = %s".format(column=column)
+            if columns.index(column) == len(columns) - 1:
+                sql += " WHERE id = {row_id}".format(row_id=row_id)
+            else:
+                sql += ", "
+        
+        print("Preparing update statement: {sql} with values: {values}, at row Id: {row_id}".format(sql=sql, values=values, row_id=row_id))
+        
+        cursor = self.get_cursor()
+        cursor.execute(sql, values)
+        
+        self.connection.commit()
+        
+        print("Successfully updated existing record with Id of {row_id} in the {table} table.".format(row_id=row_id, table=table))
+    
+    def delete_by_id(self, table, row_id):
+        """ Deletes a record in a table by its row Id, therefore only one row is deleted """
+        
+        sql = "DELETE FROM {table} WHERE id = {row_id}".format(table=table, row_id=row_id)
+        
+        print("Preparing delete statement: {sql} for record with Id: {row_id}.".format(sql=sql, row_id=row_id))
+        
+        cursor = self.get_cursor()
+        cursor.execute(sql)
+        
+        self.connection.commit()
+        
+        print("Successfully deleted record in {table} table with Id: {row_id}.".format(table=table, row_id=row_id))
\ No newline at end of file
